`MA plot <https://en.wikipedia.org/wiki/MA_plot>`_ of log fold change vs. mean of normalized counts for each gene when calculating differential expression for contrast {{ snakemake.wildcards.contrast }}.
